Crate io_ring

Crate io_ring 

Structs

AtFlags
AT_* constants for use with openat, statat, and other *at functions.
IoRing
IoringAcceptFlags
accept flags (sqe.ioprio)
IoringAsyncCancelFlags
IORING_ASYNC_CANCEL_* flags for use with io_uring_sqe.
IoringCqeFlags
IORING_CQE_F_* flags for use with io_uring_cqe.
IoringFsyncFlags
IORING_FSYNC_* flags for use with io_uring_sqe.
IoringMsgringFlags
IORING_MSG_RING_* flags for use with io_uring_sqe.
IoringPollFlags
IORING_POLL_* flags.
IoringRecvFlags
recv/recvmsg flags (sqe.ioprio)
IoringSendFlags
send/sendmsg flags (sqe.ioprio)
IoringSqeFlags
IOSQE_* flags for use with io_uring_sqe.
IoringTimeoutFlags
IORING_TIMEOUT_* and IORING_LINK_TIMEOUT_UPDATE flags for use with io_uring_sqe.
OFlags
O_* constants for use with openat.
ReadWriteFlags
RWF_* constants for use with preadv2 and pwritev2.
RecvFlags
MSG_* flags for use with recv, recvfrom, and related functions.
RenameFlags
RENAME_* constants for use with renameat_with.
SendFlags
MSG_* flags for use with send, sendto, and related functions.
SocketFlags
SOCK_* constants for use with socket_with, accept_with and acceptfrom_with.
SpliceFlags
SPLICE_F_* flags for use with io_uring_sqe.
addr3_struct
addr_len_struct
cmd_op_struct
io_uring_cqe
io_uring_ptr
A pointer in the io_uring API.
io_uring_sqe

Enums

Advice
POSIX_FADV_* constants for use with fadvise.
IoringMsgringCmds
IORING_MSG_* constants which represent commands for use with IoringOp::MsgRing, (seq.addr)
IoringOp
IORING_OP_* constants for use with io_uring_sqe.

Type Aliases

RawFd
Raw file descriptors.

Unions

addr_or_splice_off_in_union
buf_union
io_uring_user_data
User data in the io_uring API.
ioprio_union
len_union
off_or_addr2_union
op_flags_union
splice_fd_in_or_file_index_union