pub struct IoringMsgringFlags(/* private fields */);Expand description
IORING_MSG_RING_* flags for use with io_uring_sqe.
Implementations
Sourceimpl IoringMsgringFlags
impl IoringMsgringFlags
Sourcepub const CQE_SKIP: IoringMsgringFlags
pub const CQE_SKIP: IoringMsgringFlags
IORING_MSG_RING_CQE_SKIP
Sourcepub const FLAGS_PASS: IoringMsgringFlags
pub const FLAGS_PASS: IoringMsgringFlags
IORING_MSG_RING_FLAGS_PASS
Sourceimpl IoringMsgringFlags
impl IoringMsgringFlags
Sourcepub const fn empty() -> IoringMsgringFlags
pub const fn empty() -> IoringMsgringFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> IoringMsgringFlags
pub const fn all() -> IoringMsgringFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<IoringMsgringFlags>
pub const fn from_bits(bits: u32) -> Option<IoringMsgringFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> IoringMsgringFlags
pub const fn from_bits_truncate(bits: u32) -> IoringMsgringFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> IoringMsgringFlags
pub const fn from_bits_retain(bits: u32) -> IoringMsgringFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<IoringMsgringFlags>
pub fn from_name(name: &str) -> Option<IoringMsgringFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: IoringMsgringFlags) -> bool
pub const fn intersects(&self, other: IoringMsgringFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: IoringMsgringFlags) -> bool
pub const fn contains(&self, other: IoringMsgringFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: IoringMsgringFlags)
pub fn insert(&mut self, other: IoringMsgringFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: IoringMsgringFlags)
pub fn remove(&mut self, other: IoringMsgringFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: IoringMsgringFlags)
pub fn toggle(&mut self, other: IoringMsgringFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: IoringMsgringFlags, value: bool)
pub fn set(&mut self, other: IoringMsgringFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: IoringMsgringFlags) -> IoringMsgringFlags
pub const fn intersection(self, other: IoringMsgringFlags) -> IoringMsgringFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: IoringMsgringFlags) -> IoringMsgringFlags
pub const fn union(self, other: IoringMsgringFlags) -> IoringMsgringFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: IoringMsgringFlags) -> IoringMsgringFlags
pub const fn difference(self, other: IoringMsgringFlags) -> IoringMsgringFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: IoringMsgringFlags,
) -> IoringMsgringFlags
pub const fn symmetric_difference( self, other: IoringMsgringFlags, ) -> IoringMsgringFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> IoringMsgringFlags
pub const fn complement(self) -> IoringMsgringFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl IoringMsgringFlags
impl IoringMsgringFlags
Sourcepub const fn iter(&self) -> Iter<IoringMsgringFlags>
pub const fn iter(&self) -> Iter<IoringMsgringFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<IoringMsgringFlags>
pub const fn iter_names(&self) -> IterNames<IoringMsgringFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.