OFlags

Struct OFlags 

pub struct OFlags(/* private fields */);
O_* constants for use with openat.

Implementations

Source

impl OFlags

pub const ACCMODE: OFlags

O_ACCMODE

pub const RWMODE: OFlags

Similar to ACCMODE, but just includes the read/write flags, and no other flags.

On some platforms, PATH may be included in ACCMODE, when sometimes we really just want the read/write bits. Caution is indicated, as the presence of PATH may mean that the read/write bits don’t have their usual meaning.

pub const APPEND: OFlags

O_APPEND

pub const CREATE: OFlags

O_CREAT

pub const DIRECTORY: OFlags

O_DIRECTORY

pub const DSYNC: OFlags

O_DSYNC.

pub const EXCL: OFlags

O_EXCL

pub const FSYNC: OFlags

O_FSYNC.

pub const NOFOLLOW: OFlags

O_NOFOLLOW

pub const NONBLOCK: OFlags

O_NONBLOCK

pub const RDONLY: OFlags

O_RDONLY

pub const WRONLY: OFlags

O_WRONLY

pub const RDWR: OFlags

O_RDWR

This is not equal to RDONLY | WRONLY. It’s a distinct flag.

pub const NOCTTY: OFlags

O_NOCTTY

pub const RSYNC: OFlags

O_RSYNC.

pub const SYNC: OFlags

O_SYNC

pub const TRUNC: OFlags

O_TRUNC

pub const PATH: OFlags

O_PATH

pub const CLOEXEC: OFlags

O_CLOEXEC

pub const TMPFILE: OFlags

O_TMPFILE

pub const NOATIME: OFlags

O_NOATIME

pub const DIRECT: OFlags

O_DIRECT

pub const LARGEFILE: OFlags

O_LARGEFILE

Note that rustix and/or libc will automatically set this flag when appropriate on open(2) and friends, thus typical users do not need to care about it. It will may be reported in return of fcntl_getfl, though.

Source

impl OFlags

pub const fn empty() -> OFlags

Get a flags value with all bits unset.

pub const fn all() -> OFlags

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<OFlags>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> OFlags

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> OFlags

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<OFlags>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: OFlags) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: OFlags) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: OFlags)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: OFlags)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: OFlags)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: OFlags, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: OFlags) -> OFlags

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: OFlags) -> OFlags

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: OFlags) -> OFlags

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: OFlags) -> OFlags

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> OFlags

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl OFlags

pub const fn iter(&self) -> Iter<OFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<OFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.